@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: configfile.h,v 1.40 2005/04/27 02:44:16 dave_malcolm Exp $ */
+/* $Id: configfile.h 958 2006-09-02 20:27:07Z herzi $ */
 
 #ifndef GQ_CONFIGFILE_H_INCLUDED
 #define GQ_CONFIGFILE_H_INCLUDED
@@ -31,6 +31,7 @@
 #include <glib.h>
 
 #include "common.h"
+#include "gq-tab-search.h"
 #include "util.h"
 
 #define CURRENT_CONFIG_VERSION	3
@@ -98,10 +99,9 @@ struct gq_config {
      long last_asked;    /* timestamp of lask asking for upgrade to a
 			    newer config file. */
 
-     GList *servers;
      GList *templates;
      GList *filters;
-     int search_argument;
+     GqSearchType search_argument;
      int ldifformat;
      int confirm_mod; /* not used yet */
      int showdn;
@@ -170,37 +170,10 @@ void config_write_string(struct writeconfig *wc,
 			 const char *value,
 			 const char *entity, GHashTable *attr);
 void config_write_string_ne(struct writeconfig *wc,
-			    const char *value, 
+			    const char *value,
 			    const char *entity, GHashTable *attr);
 
 
-void config_add_server(struct gq_config *config, 
-		       struct ldapserver *newserver);
-void config_remove_server(struct gq_config *config, 
-			  struct ldapserver *server);
-
-struct ldapserver *new_ldapserver(void);
-void free_ldapserver(struct ldapserver *server);
-
-/** NOTE: copy_ldapserver ONLY copies the configuration
-    information. It DOES NOT copy the operational stuff. Often you
-    will want to call reset_ldapserver(target) alongside of
-    copy_ldapserver.  */
-void copy_ldapserver(struct ldapserver *target, 
-		     const struct ldapserver *source);
-
-/** NOTE: reset_ldapserver sets the target refcount to 0 */
-void reset_ldapserver(struct ldapserver *target);
-
-/* canonicalize_ldapserver - to be called whenever the server-related
-   information gets changed for the server in order to recalculate
-   some dependent information. Eg. a change to the ldaphost might
-   change the fact that a server get specified via an ldap URI or
-   not. Another example is the change of the ldaphost causing a change
-   to the canonical name of the server. This is where the name
-   originated. */
-void canonicalize_ldapserver(struct ldapserver *server);
-
 char *homedir(void);
 
 /* filename_config returns the name of the config file. The returned
@@ -215,8 +188,8 @@ void init_config(void);
 struct gq_config *new_config(void);
 void free_config(struct gq_config *cfg);
 
-void transient_add_server(struct ldapserver *newserver);
-void transient_remove_server(struct ldapserver *server);
+void transient_add_server(GqServer *newserver);
+void transient_remove_server(GqServer *server);
 
 extern struct gq_config *config;
 extern GList *transient_servers;
