@@ -22,9 +22,11 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: dt_oc.c,v 1.22 2006/04/05 00:53:55 herzi Exp $ */
+/* $Id: dt_oc.c 975 2006-09-07 18:44:41Z herzi $ */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif /* HAVE_CONFIG_H */
 
 /* Doesn't make sense without schema information */
 #ifdef HAVE_LDAP_STR2OBJECTCLASS
@@ -35,45 +37,24 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <stdio.h>	/* snprintf */
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
 #include "dt_oc.h"
 
 #include "common.h"
+#include "gq-tab-browse.h"
 #include "util.h"
 #include "errorchain.h"
 #include "input.h"
 #include "tinput.h"
-#include "browse.h"
 #include "encode.h"
 #include "ldif.h" /* for b64_decode */
 #include "syntax.h"
 #include "schema.h"
-#include "i18n.h"
-
-static dt_oc_handler dt_oc_handler_vtab = {
-     {
-	  "Objectclass", 
-	  FALSE,
-	  TRUE,
-	  dt_oc_get_widget,
-	  dt_oc_get_data,
-	  dt_oc_set_data,
-	  bervalLDAPMod
-     },
-     identity, /* encode method */
-     identity, /* decode method */
-};
-
-display_type_handler *dt_oc_get_handler() {
-     return (display_type_handler *) &dt_oc_handler_vtab;
-}
-
-
 
 struct change_info {
      struct inputform *iform;
@@ -89,7 +70,7 @@ static void free_change_info(struct change_info *ci) {
      if (ci->newtext) g_free(ci->newtext);
      if (ci->oldtext) g_free(ci->oldtext);
      ci->newtext = ci->oldtext = NULL;
-     
+
      if (ci->id) {
 	  gtk_timeout_remove(ci->id);
 	  ci->id = 0;
@@ -110,17 +91,17 @@ static gboolean do_change(int error_context, struct change_info *ci);
    normally we register a timeout job to wait until selection via the
    combo is done. This is sooooo dirty!! */
 
-static int timeout_oc(struct change_info *ci) 
+static int timeout_oc(struct change_info *ci)
 {
      GtkCombo *c = GTK_COMBO(ci->combo);
      GtkEntry *e = GTK_ENTRY(c->entry);
 
 /*       printf("idle check %08x %08x %08x %08x\n",  */
-/*  	    GTK_WIDGET_FLAGS (c->list), */
-/*  	    GTK_WIDGET_FLAGS (c->popup), */
-/*  	    GTK_WIDGET_VISIBLE(c->popwin), */
-/*  	    GTK_WIDGET_FLAGS (c->popwin) */
-/*  	    ); */
+/*	    GTK_WIDGET_FLAGS (c->list), */
+/*	    GTK_WIDGET_FLAGS (c->popup), */
+/*	    GTK_WIDGET_VISIBLE(c->popwin), */
+/*	    GTK_WIDGET_FLAGS (c->popwin) */
+/*	    ); */
 
      /* NOTE :: ATTENTION :: NOTE
 
@@ -132,17 +113,17 @@ static int timeout_oc(struct change_info *ci)
 	  gchar *newtext;
 	  gboolean rebuild = FALSE;
 	  int ctx;
-	  
+
 	  gtk_timeout_remove(ci->id);
 	  ci->id = 0;
 
-/*  	  printf("working!!\n"); */
+/*	  printf("working!!\n"); */
 
 	  newtext = gtk_editable_get_chars(GTK_EDITABLE(e), 0, -1);
 	  if (ci->newtext) g_free(ci->newtext);
 	  ci->newtext = newtext;
 
-	  ctx = error_new_context(_("Changing objectClass attribute"), 
+	  ctx = error_new_context(_("Changing objectClass attribute"),
 				  GTK_WIDGET(c));
 
 	  rebuild = do_change(ctx, ci);
@@ -188,7 +169,7 @@ static gboolean check_if_any_oc_needs(GList *oclist, LDAPAttributeType *at,
 
 static void new_oc(GtkEditable *entry, struct change_info *ci)
 {
-     if (ci->id == 0) 
+     if (ci->id == 0)
 	  ci->id = gtk_timeout_add(25,
 				   (GtkFunction)timeout_oc,
 				   ci);
@@ -199,7 +180,7 @@ static gboolean do_change(int error_context, struct change_info *ci)
      gchar *newtext = ci->newtext;
      gchar *oldtext = ci->oldtext;
      struct formfill *form;
-     struct ldapserver *server;
+     GqServer *server;
      GList *formlist, *tmplist = NULL;
      int i, n = 0;
      struct server_schema *ss;
@@ -248,15 +229,15 @@ static gboolean do_change(int error_context, struct change_info *ci)
 		    }
 
 		    if (!found) {
-			 /* this will fire the change signals again, thus 
+			 /* this will fire the change signals again, thus
 			    the changeinfo data structure may not be freed */
 			 gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(ci->combo)->entry), oldtext);
 			 g_free(newtext);
 			 ci->newtext = NULL;
-			 
+
 			 error_push(error_context,
 				    _("Missing superior objectClass %s"), *cp);
-			 
+
 			 return FALSE;
 		    }
 	       }
@@ -268,7 +249,7 @@ static gboolean do_change(int error_context, struct change_info *ci)
 
      if (strlen(oldtext) > 0) {
 	  /* removed objectClass */
-/*  	  printf("del %s\n", oldtext); */
+/*	  printf("del %s\n", oldtext); */
 	  oc = find_oc_by_oc_name(ss, oldtext);
 
 	  /* NOTE: cannot remove top objectClass */
@@ -286,26 +267,26 @@ static gboolean do_change(int error_context, struct change_info *ci)
 			 gchar *c = g_malloc(gb->len + 1);
 			 memcpy(c, gb->data, gb->len);
 			 c[gb->len] = 0;
-			 
+
 			 oc2 = find_oc_by_oc_name(ss, c);
-			 
+
 			 /* filter out the to-be-deleted objectClass */
 			 if (oc2 == oc) {
 			      g_free(c);
 			      continue;
 			 }
-			 
+
 			 tmplist = g_list_append(tmplist, oc2);
-			 
+
 			 g_free(c);
 		    }
 	       }
-	       
+
 	       /* Mark no-longer-needed attributes */
 
 	       /* required attributes */
 	       for(i = 0; oc->oc_at_oids_must && oc->oc_at_oids_must[i]; i++) {
-		    /* does any other objectclass require/allow 
+		    /* does any other objectclass require/allow
 		       this attribute? */
 
 		    at = find_canonical_at_by_at(ss, oc->oc_at_oids_must[i]);
@@ -313,7 +294,7 @@ static gboolean do_change(int error_context, struct change_info *ci)
 
 		    if (!check_if_any_oc_needs(tmplist, at, ss)) {
 			 form = lookup_attribute_using_schema(formlist,
-							      oc->oc_at_oids_must[i], 
+							      oc->oc_at_oids_must[i],
 							      ss, NULL);
 			 if (form) {
 			      form->flags |= FLAG_DEL_ME;
@@ -324,7 +305,7 @@ static gboolean do_change(int error_context, struct change_info *ci)
 
 	       /* allowed attributes */
 	       for(i = 0; oc->oc_at_oids_may && oc->oc_at_oids_may[i]; i++) {
-		    /* does any other objectclass require/allow 
+		    /* does any other objectclass require/allow
 		       this attribute? */
 
 		    at = find_canonical_at_by_at(ss, oc->oc_at_oids_may[i]);
@@ -332,7 +313,7 @@ static gboolean do_change(int error_context, struct change_info *ci)
 		    if (!at) continue;
 		    if (!check_if_any_oc_needs(tmplist, at, ss)) {
 			 form = lookup_attribute_using_schema(formlist,
-							      oc->oc_at_oids_may[i], 
+							      oc->oc_at_oids_may[i],
 							      ss, NULL);
 			 if (form) {
 			      form->flags |= FLAG_DEL_ME;
@@ -355,20 +336,19 @@ static gboolean do_change(int error_context, struct change_info *ci)
 	       /* required attributes */
 	       for(i = 0; oc->oc_at_oids_must && oc->oc_at_oids_must[i]; i++) {
 		    form = lookup_attribute_using_schema(formlist,
-							 oc->oc_at_oids_must[i], 
+							 oc->oc_at_oids_must[i],
 							 ss, &at);
 		    if (form) {
 			 form->flags &= ~FLAG_DEL_ME;
 			 continue;
 		    }
 		    form = new_formfill();
-		    assert(form);
+		    g_assert(form);
 
-		    form->server = server;
-		    ldapserver_ref(server);
+		    form->server = g_object_ref(server);
 
-		    strncpy(form->attrname, oc->oc_at_oids_must[i],
-			    MAX_ATTR_LEN);
+		    g_free(form->attrname);
+		    form->attrname = g_strdup(oc->oc_at_oids_must[i]);
 		    form->flags |= FLAG_MUST_IN_SCHEMA;
 		    if (at && at->at_single_value) {
 			 form->flags |= FLAG_SINGLE_VALUE;
@@ -392,13 +372,12 @@ static gboolean do_change(int error_context, struct change_info *ci)
 		    }
 
 		    form = new_formfill();
-		    assert(form);
+		    g_assert(form);
 
-		    form->server = server;
-		    ldapserver_ref(server);
+		    form->server = g_object_ref(server);
 
-		    strncpy(form->attrname, oc->oc_at_oids_may[i],
-			    MAX_ATTR_LEN);
+		    g_free(form->attrname);
+		    form->attrname = g_strdup(oc->oc_at_oids_may[i]);
 		    if (at && at->at_single_value) {
 			 form->flags |= FLAG_SINGLE_VALUE;
 		    }
@@ -424,13 +403,13 @@ static gboolean do_change(int error_context, struct change_info *ci)
 
 GtkWidget *dt_oc_get_widget(int error_context,
 			    struct formfill *form, GByteArray *data,
-			    GtkSignalFunc *activatefunc,
-			    gpointer funcdata) 
+			    GCallback *activatefunc,
+			    gpointer funcdata)
 {
      GtkWidget *combo;
      GList *oclist;
      GList *pop = NULL;
-     struct ldapserver *server;
+     GqServer *server;
      struct server_schema *ss;
      struct change_info *ci;
      struct inputform *iform;
@@ -448,7 +427,7 @@ GtkWidget *dt_oc_get_widget(int error_context,
 
      if (ss) {
 	  /* turn data->data into a nul terminated string ... */
-	  
+
 	  if (data) {
 	       octmp = g_malloc0( data->len + 1);
 	       strncpy(octmp, (gchar*)data->data, data->len); /* UTF-8 OK */
@@ -460,12 +439,12 @@ GtkWidget *dt_oc_get_widget(int error_context,
 		    if (octmp && strcasecmp(oc->oc_names[0], octmp) == 0) {
 			 /* add the current objectClass as the first
 			    element to the dropdown list.
-			    
+
 			    NOTE: we lookup the objectclass from the list,
 			    as we want to use a fixed string for the list -
 			    we cannot just strdup the data->data stuff, as
 			    we would never be able to free it!!! */
-			 
+
 			 pop = g_list_insert(pop, oc->oc_names[0], 0);
 		    } else {
 			 pop = g_list_append(pop, oc->oc_names[0]);
@@ -473,12 +452,12 @@ GtkWidget *dt_oc_get_widget(int error_context,
 	       }
 	       oclist = g_list_next(oclist);
 	  }
-	  
+
 	  if (octmp) g_free(octmp);
-	  
+
 	  gtk_combo_set_popdown_strings(GTK_COMBO(combo),
 				   pop);
-	  
+
 	  if (pop) g_list_free(pop);
 
 	  gtk_editable_set_editable(GTK_EDITABLE(GTK_COMBO(combo)->entry),
@@ -502,17 +481,18 @@ GtkWidget *dt_oc_get_widget(int error_context,
 
      dt_oc_set_data(form, data, combo);
 
-     gtk_signal_connect_after(GTK_OBJECT(GTK_COMBO(combo)->entry),
+     g_signal_connect_after(GTK_COMBO(combo)->entry,
 			      "changed",
-			      GTK_SIGNAL_FUNC(new_oc),
-			      (gpointer) ci);
+			      G_CALLBACK(new_oc),
+			      ci);
 
      return combo;
 }
 
 
-GByteArray *dt_oc_get_data(struct formfill *form, GtkWidget *widget) 
+GByteArray *dt_oc_get_data(struct formfill *form, GtkWidget *widget)
 {
+	GQTypeDisplayClass* klass;
     GByteArray *copy;
     int l;
 
@@ -525,13 +505,15 @@ GByteArray *dt_oc_get_data(struct formfill *form, GtkWidget *widget)
 	return NULL;
     }
 
-    copy = DT_ENTRY(form->dt_handler)->decode(content, strlen(content));
-    
+    klass = g_type_class_ref(form->dt_handler);
+    copy = DT_ENTRY(klass)->decode(content, strlen(content));
+    g_type_class_unref(klass);
+
 /*      printf("getting orgtext '%s' text '%s' orglen=%d len1=%d len2=%d\n", */
-/*  	   content, */
-/*  	   copy->data, */
-/*  	   strlen(content), */
-/*  	   copy->len, strlen(copy->data)); */
+/*	   content, */
+/*	   copy->data, */
+/*	   strlen(content), */
+/*	   copy->len, strlen(copy->data)); */
 
     g_free(content);
 
@@ -539,20 +521,20 @@ GByteArray *dt_oc_get_data(struct formfill *form, GtkWidget *widget)
 }
 
 void dt_oc_set_data(struct formfill *form, GByteArray *data,
-		    GtkWidget *widget) 
+		    GtkWidget *widget)
 {
      struct change_info *ci = gtk_object_get_data(GTK_OBJECT(widget), "ci");
- 
+
      if (ci->oldtext) g_free(ci->oldtext);
      if(data) {
+          GQDisplayOCClass* klass = g_type_class_ref(form->dt_handler);
 	  guchar g = '\0';
 
-	  GByteArray *encoded =
-	       DT_ENTRY(form->dt_handler)->encode((gchar*)data->data, data->len);
-	  /*  	printf("setting text '%s' orglen=%d len1=%d len2=%d\n", */
-	  /*  	       encoded->data, */
-	  /*  	       data->len, */
-	  /*  	       encoded->len, strlen(encoded->data)); */
+	  GByteArray *encoded = DT_ENTRY(klass)->encode((gchar*)data->data, data->len);
+	  /*	printf("setting text '%s' orglen=%d len1=%d len2=%d\n", */
+	  /*	       encoded->data, */
+	  /*	       data->len, */
+	  /*	       encoded->len, strlen(encoded->data)); */
 	  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(widget)->entry),
 			     (gchar*)encoded->data);
 	  g_byte_array_append(encoded, &g, 1);
@@ -560,15 +542,35 @@ void dt_oc_set_data(struct formfill *form, GByteArray *data,
 	  ci->oldtext = (gchar*)encoded->data;
 
 	  g_byte_array_free(encoded, FALSE);
+	  g_type_class_unref(klass);
      } else {
 	  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(widget)->entry), "");
 	  ci->oldtext = g_strdup("");
      }
 }
+
+/* GType */
+G_DEFINE_TYPE(GQDisplayOC, gq_display_oc, GQ_TYPE_DISPLAY_ENTRY);
+
+static void
+gq_display_oc_init(GQDisplayOC* self) {}
+
+static void
+gq_display_oc_class_init(GQDisplayOCClass* self_class) {
+	GQTypeDisplayClass * gtd_class = GQ_TYPE_DISPLAY_CLASS(self_class);
+	GQDisplayEntryClass* gde_class = GQ_DISPLAY_ENTRY_CLASS(self_class);
+
+	gtd_class->name = Q_("displaytype|Object Class");
+	gtd_class->selectable = FALSE;
+	gtd_class->show_in_search_result = TRUE;
+	gtd_class->get_widget = dt_oc_get_widget;
+	gtd_class->get_data = dt_oc_get_data;
+	gtd_class->set_data = dt_oc_set_data;
+	gtd_class->buildLDAPMod = bervalLDAPMod;
+
+	gde_class->encode = identity;
+	gde_class->decode = identity;
+};
+
 #endif /* HAVE_LDAP_STR2OBJECTCLASS */
 
-/* 
-   Local Variables:
-   c-basic-offset: 5
-   End:
- */
