@@ -22,9 +22,11 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: filter.c,v 1.29 2006/04/05 00:53:55 herzi Exp $ */
+/* $Id: filter.c 975 2006-09-07 18:44:41Z herzi $ */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif /* HAVE_CONFIG_H */
 
 #include <string.h>
 #include <stdio.h>
@@ -36,10 +38,12 @@
 #endif /* HAVE_ISWSPACE */
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "common.h"
-#include "gq.h"
+#include "gq-server-list.h"
+#include "gq-tab-search.h"
 #include "util.h"
 #include "configfile.h"
 #include "search.h"
@@ -47,7 +51,6 @@
 #include "filter.h"
 #include "errorchain.h"
 #include "debug.h"
-#include "i18n.h"
 #include "input.h"
 #include "state.h"
 
@@ -85,10 +88,10 @@ struct gq_filter *new_filter()
 
 void free_filter(struct gq_filter *filter) 
 {
-     g_free_if(filter->name);
-     g_free_if(filter->ldapfilter);
-     g_free_if(filter->servername);
-     g_free_if(filter->basedn);
+     g_free(filter->name);
+     g_free(filter->ldapfilter);
+     g_free(filter->servername);
+     g_free(filter->basedn);
      g_free(filter);
 }
 
@@ -126,8 +129,8 @@ void add_filter(GtkWidget *filternamebox)
      GtkWidget *server_combo, *searchbase_combo;
      GList *filterlist;
      struct gq_filter *filter;
-     struct ldapserver *server;
-     struct tab *tab;
+     GqServer *server;
+     GqTab *tab;
      char *filterstring, *searchstring, *servername, *searchbase, msg[192];
      const char *filtername;
 
@@ -138,9 +141,9 @@ void add_filter(GtkWidget *filternamebox)
      if(tab->type != SEARCH_MODE)
 	  return;
 
-     server_combo = SEARCHTAB(tab)->serverlist_combo;
+     server_combo = GQ_TAB_SEARCH(tab)->serverlist_combo;
      servername = gtk_editable_get_chars(GTK_EDITABLE(GTK_COMBO(server_combo)->entry), 0, -1);
-     if( (server = server_by_name(servername)) == NULL) {
+     if( (server = gq_server_list_get_by_name(gq_server_list_get(), servername)) == NULL) {
 	  g_free(servername);
 	  return;
      }
@@ -175,7 +178,7 @@ void add_filter(GtkWidget *filternamebox)
 	       filter = (struct gq_filter *) filterlist->data;
 	       if(!strncasecmp(filter->name, filtername, 
 			       MAX_FILTERNAME_LEN - 1)) {
-		    snprintf(msg, sizeof(msg), 
+		    g_snprintf(msg, sizeof(msg), 
 			     _("There is already a filter called '%s'"), filtername);
 		    single_warning_popup(msg);
 		    return;
@@ -192,13 +195,13 @@ void add_filter(GtkWidget *filternamebox)
 	  /* check state of Remember... button, and get servername/basedn if active */
 	  button = gtk_object_get_data(GTK_OBJECT(filternamebox), "saveserver");
 	  if(GTK_TOGGLE_BUTTON(button)->active) {
-	       searchbase_combo = SEARCHTAB(tab)->searchbase_combo;
+	       searchbase_combo = GQ_TAB_SEARCH(tab)->searchbase_combo;
 	       searchbase = gtk_editable_get_chars(GTK_EDITABLE(GTK_COMBO(searchbase_combo)->entry), 0, -1);
 
-	       g_free_if(filter->servername);
+	       g_free(filter->servername);
 	       filter->servername = servername;
 
-	       g_free_if(filter->basedn);
+	       g_free(filter->basedn);
 	       filter->basedn = searchbase;
 	  }
 
@@ -230,9 +233,9 @@ static void name_popup(void)
      gtk_window_set_title(GTK_WINDOW(window), _("Filter name"));
      gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, FALSE);
 
-     gtk_signal_connect_object(GTK_OBJECT(window), "key_press_event",
-                               GTK_SIGNAL_FUNC(close_on_esc),
-                               (gpointer) window);
+     g_signal_connect_swapped(window, "key_press_event",
+                               G_CALLBACK(close_on_esc),
+                               window);
 
      vbox1 = GTK_DIALOG(window)->vbox;
      gtk_widget_show(vbox1);
@@ -248,8 +251,8 @@ static void name_popup(void)
      GTK_WIDGET_SET_FLAGS(filternamebox, GTK_CAN_FOCUS);
      GTK_WIDGET_SET_FLAGS(filternamebox, GTK_CAN_DEFAULT);
      gtk_widget_show(filternamebox);
-     gtk_signal_connect_object(GTK_OBJECT(filternamebox), "activate",
-			       GTK_SIGNAL_FUNC(add_filter),
+     g_signal_connect_swapped(filternamebox, "activate",
+			       G_CALLBACK(add_filter),
 			       GTK_OBJECT(filternamebox));
      gtk_box_pack_start(GTK_BOX(vbox1), filternamebox, TRUE, TRUE, 0);
 
@@ -271,13 +274,10 @@ static void name_popup(void)
      gtk_widget_show(hbox0);
      gtk_box_pack_start(GTK_BOX(vbox2), hbox0, TRUE, TRUE, 0);
 
-#if GTK_MAJOR >= 2
      button = gtk_button_new_from_stock(GTK_STOCK_OK);
-#else
-     button = gq_button_new_with_label(_("_OK"));
-#endif
-     gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                               GTK_SIGNAL_FUNC(add_filter),
+
+     g_signal_connect_swapped(button, "clicked",
+                               G_CALLBACK(add_filter),
 			       GTK_OBJECT(filternamebox));
 
      gtk_box_pack_start(GTK_BOX(hbox0), button, FALSE, FALSE, 0);
@@ -287,13 +287,10 @@ static void name_popup(void)
      gtk_widget_show(button);
 
 
-#if GTK_MAJOR >= 2
      button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-#else
-     button = gq_button_new_with_label(_("_Cancel"));
-#endif
-     gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                               GTK_SIGNAL_FUNC(gtk_widget_destroy),
+
+     g_signal_connect_swapped(button, "clicked",
+                               G_CALLBACK(gtk_widget_destroy),
 			       GTK_OBJECT(window));
 
      gtk_box_pack_start(GTK_BOX(hbox0), button, FALSE, FALSE, 0);
@@ -309,7 +306,7 @@ static void name_popup(void)
 void filter_selected(struct gq_filter *filter)
 {
      GtkWidget *focusbox, *server_combo, *searchbase_combo;
-     struct tab *tab;
+     GqTab *tab;
 
      /* find current tab */
      tab = mainwin_get_current_tab(mainwin.mainbook);
@@ -336,20 +333,20 @@ void filter_selected(struct gq_filter *filter)
 
      /* set server combo to this filter's server */
      if(filter->servername[0]) {
-	  server_combo = SEARCHTAB(tab)->serverlist_combo;
+	  server_combo = GQ_TAB_SEARCH(tab)->serverlist_combo;
 	  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(server_combo)->entry),
 			     filter->servername);
      }
 
      /* set searchbase combo to this filter's base DN */
      if(filter->basedn[0]) {
-	  searchbase_combo = SEARCHTAB(tab)->searchbase_combo;
+	  searchbase_combo = GQ_TAB_SEARCH(tab)->searchbase_combo;
 	  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(searchbase_combo)->entry),
 			     filter->basedn);
      }
 
      /* uhhh, what a hack */
-     gtk_signal_emit_by_name(GTK_OBJECT(focusbox), "activate");
+     g_signal_emit_by_name(focusbox, "activate");
 }
 
 
@@ -365,14 +362,14 @@ void show_filters(void)
      char *clist_content[5];
 
      window = stateful_gtk_window_new(GTK_WINDOW_TOPLEVEL,
-				      "filterlist", 670, 350); 
+				      "filterlist", 670, 350);
 
      gtk_container_border_width(GTK_CONTAINER(window), CONTAINER_BORDER_WIDTH);
      gtk_window_set_title(GTK_WINDOW(window), _("Filters"));
 
-     gtk_signal_connect_object(GTK_OBJECT(window), "key_press_event",
-                               GTK_SIGNAL_FUNC(close_on_esc),
-                               (gpointer) window);
+     g_signal_connect_swapped(window, "key_press_event",
+                               G_CALLBACK(close_on_esc),
+                               window);
 
      vbox1 = gtk_vbox_new(FALSE, 0);
      gtk_widget_show(vbox1);
@@ -386,11 +383,8 @@ void show_filters(void)
      gtk_widget_show(hbox1);
      gtk_box_pack_start(GTK_BOX(hbox0), hbox1, FALSE, FALSE, 0);
 
-#if GTK_MAJOR >= 2
      new_button = gtk_button_new_from_stock(GTK_STOCK_NEW);
-#else
-     new_button = gq_button_new_with_label(_("_New"));
-#endif
+
      GTK_WIDGET_UNSET_FLAGS(new_button, GTK_CAN_DEFAULT);
 #ifdef OLD_FOCUS_HANDLING
      GTK_WIDGET_UNSET_FLAGS(new_button, GTK_CAN_FOCUS);
@@ -398,11 +392,8 @@ void show_filters(void)
      gtk_widget_show(new_button);
      gtk_box_pack_start(GTK_BOX(hbox1), new_button, FALSE, FALSE, 0);
 
-#if GTK_MAJOR >= 2
      delete_button = gtk_button_new_from_stock(GTK_STOCK_DELETE);
-#else
-     delete_button = gq_button_new_with_label(_("_Delete"));
-#endif
+
      GTK_WIDGET_UNSET_FLAGS(delete_button, GTK_CAN_DEFAULT);
 #ifdef OLD_FOCUS_HANDLING
      GTK_WIDGET_UNSET_FLAGS(delete_button, GTK_CAN_FOCUS);
@@ -410,11 +401,8 @@ void show_filters(void)
      gtk_widget_show(delete_button);
      gtk_box_pack_start(GTK_BOX(hbox1), delete_button, FALSE, FALSE, 5);
 
-#if GTK_MAJOR >= 2
      copy_button = gtk_button_new_from_stock(GTK_STOCK_COPY);
-#else
-     copy_button = gq_button_new_with_label(_("_Copy"));
-#endif
+
      GTK_WIDGET_UNSET_FLAGS(copy_button, GTK_CAN_DEFAULT);
      GTK_WIDGET_UNSET_FLAGS(copy_button, GTK_CAN_FOCUS);
      gtk_widget_show(copy_button);
@@ -431,10 +419,10 @@ void show_filters(void)
      gtk_widget_show(filter_clist);
      gtk_container_add(GTK_CONTAINER(scrwin), filter_clist);
      gtk_clist_column_titles_passive(GTK_CLIST(filter_clist));
-     gtk_signal_connect_object(GTK_OBJECT(filter_clist), "select_row",
-			       GTK_SIGNAL_FUNC(filterlist_row_selected), (gpointer) filter_clist);
-     gtk_signal_connect_object(GTK_OBJECT(filter_clist), "unselect_row",
-			       GTK_SIGNAL_FUNC(filterlist_row_unselected), (gpointer) filter_clist);
+     g_signal_connect_swapped(filter_clist, "select_row",
+			       G_CALLBACK(filterlist_row_selected), filter_clist);
+     g_signal_connect_swapped(filter_clist, "unselect_row",
+			       G_CALLBACK(filterlist_row_unselected), filter_clist);
      for(i = 0; i < 3; i++) {
 	  gtk_clist_set_column_width(GTK_CLIST(filter_clist), i, 100);
      }
@@ -459,31 +447,28 @@ void show_filters(void)
      gtk_widget_show(hbox2);
      gtk_box_pack_start(GTK_BOX(vbox1), hbox2, FALSE, FALSE, 5);
 
-#if GTK_MAJOR >= 2
      ok_button = gtk_button_new_from_stock(GTK_STOCK_OK);
-#else
-     ok_button = gq_button_new_with_label(_("_OK"));
-#endif
+
      gtk_widget_show(ok_button);
      gtk_box_pack_start(GTK_BOX(hbox2), ok_button, FALSE, FALSE, 0);
      GTK_WIDGET_SET_FLAGS(ok_button, GTK_CAN_DEFAULT);
      GTK_WIDGET_SET_FLAGS(ok_button, GTK_RECEIVES_DEFAULT);
      gtk_widget_grab_default(ok_button);
-     gtk_signal_connect_object(GTK_OBJECT(ok_button), "clicked",
-                               (GtkSignalFunc) gtk_widget_destroy,
-                               (gpointer) window);
+     g_signal_connect_swapped(ok_button, "clicked",
+                               G_CALLBACK(gtk_widget_destroy),
+                               window);
 
      /* can only pass the clist to new/delete/copy buttons after it was created */
-     gtk_signal_connect_object(GTK_OBJECT(new_button), "clicked",
-			       GTK_SIGNAL_FUNC(add_new_filter_callback), (gpointer) filter_clist);
+     g_signal_connect_swapped(new_button, "clicked",
+			       G_CALLBACK(add_new_filter_callback), filter_clist);
 
-     gtk_signal_connect(GTK_OBJECT(delete_button), "clicked",
-			GTK_SIGNAL_FUNC(delete_filter),
-			(gpointer) filter_clist);
+     g_signal_connect(delete_button, "clicked",
+			G_CALLBACK(delete_filter),
+			filter_clist);
 
-     gtk_signal_connect_object(GTK_OBJECT(copy_button), "clicked",
-			       GTK_SIGNAL_FUNC(copy_existing_filter),
-			       (gpointer) filter_clist);
+     g_signal_connect_swapped(copy_button, "clicked",
+			       G_CALLBACK(copy_existing_filter),
+			       filter_clist);
 
      gtk_widget_show(window);
 
@@ -606,9 +591,7 @@ static void remove_from_filtermenu(struct gq_filter *filter)
 static void edit_filter(GtkCList *filter_clist, int is_new_filter, 
 			int row, struct gq_filter *filter)
 {
-#if GTK_MAJOR >= 2
      GtkWidget *scrolled;
-#endif
      GtkWidget *window, *vbox1, *hbox1, *hbox2, *label, *entry;
      GtkWidget *table1, *indent, *editbox, *save, *cancel;
      char *indented;
@@ -624,9 +607,9 @@ static void edit_filter(GtkCList *filter_clist, int is_new_filter,
      gtk_container_border_width(GTK_CONTAINER(window), CONTAINER_BORDER_WIDTH);
      gtk_window_set_title(GTK_WINDOW(window), _("Edit filter"));
 
-     gtk_signal_connect_object(GTK_OBJECT(window), "key_press_event",
-                               GTK_SIGNAL_FUNC(close_on_esc),
-                               (gpointer) window);
+     g_signal_connect_swapped(window, "key_press_event",
+                               G_CALLBACK(close_on_esc),
+                               window);
 
      vbox1 = gtk_vbox_new(FALSE, 0);
      gtk_widget_show(vbox1);
@@ -654,9 +637,7 @@ static void edit_filter(GtkCList *filter_clist, int is_new_filter,
      gtk_table_attach(GTK_TABLE(table1), entry, 1, 2, 0, 1,
 		      GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
-#if GTK_MAJOR >= 2
      gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
-#endif
 
      /* Server */
      label = gq_label_new(_("_Server"));
@@ -673,9 +654,7 @@ static void edit_filter(GtkCList *filter_clist, int is_new_filter,
      gtk_table_attach(GTK_TABLE(table1), entry, 1, 2, 1, 2,
 		      GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
-#if GTK_MAJOR >= 2
      gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
-#endif
 
      /* Base DN */
      label = gq_label_new(_("_Base DN"));
@@ -704,11 +683,8 @@ static void edit_filter(GtkCList *filter_clist, int is_new_filter,
      gtk_widget_show(indent);
      gtk_box_pack_start(GTK_BOX(hbox1), indent, FALSE, FALSE, 0);
 
-#if GTK_MAJOR >= 2
      gtk_label_set_mnemonic_widget(GTK_LABEL(label), entry);
-#endif
 
-#if GTK_MAJOR >= 2
      scrolled = gtk_scrolled_window_new(NULL, NULL);
      gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled), 
 				    GTK_POLICY_AUTOMATIC,
@@ -736,66 +712,35 @@ static void edit_filter(GtkCList *filter_clist, int is_new_filter,
      gtk_box_pack_start(GTK_BOX(vbox1), scrolled, TRUE, TRUE, 3);
      gtk_widget_show(editbox);
      gtk_widget_show(scrolled);
-#else
-     editbox = gtk_text_new(NULL, NULL);
 
-     gtk_object_set_data(GTK_OBJECT(window), "editbox", editbox);
-     gtk_text_set_editable(GTK_TEXT(editbox), TRUE);
-     gtk_text_set_word_wrap(GTK_TEXT(editbox), FALSE);
-     gtk_text_set_line_wrap(GTK_TEXT(editbox), FALSE);
-     GTK_WIDGET_SET_FLAGS(editbox, GTK_CAN_FOCUS);
-
-     /* populate editbox */
-     if(filter) {
-	  indented = indent_filter(filter->ldapfilter);
-	  gtk_text_insert(GTK_TEXT(editbox), FILTER_EDIT_FONT, NULL, NULL, indented, -1);
-	  g_free(indented);
-     }
-     else {
-	  /* insert, then delete a space. This gets the font info into the widget... */
-	  gtk_text_insert(GTK_TEXT(editbox), FILTER_EDIT_FONT, NULL, NULL, " ", -1);
-	  gtk_text_backward_delete(GTK_TEXT(editbox), 1);
-     }
-     gtk_text_set_point(GTK_TEXT(editbox), 0);
-     gtk_widget_show(editbox);
-
-     gtk_box_pack_start(GTK_BOX(vbox1), editbox, TRUE, TRUE, 3);
-#endif
-
-     gtk_signal_connect(GTK_OBJECT(indent), "toggled",
-			GTK_SIGNAL_FUNC(indent_toggled), (gpointer) editbox);
+     g_signal_connect(indent, "toggled",
+			G_CALLBACK(indent_toggled), editbox);
 
 
      hbox2 = gtk_hbutton_box_new(); /* box_new(FALSE, 0); */
      gtk_widget_show(hbox2);
      gtk_box_pack_start(GTK_BOX(vbox1), hbox2, FALSE, FALSE, 0);
 
-#if GTK_MAJOR >= 2
      save = gtk_button_new_from_stock(GTK_STOCK_SAVE);
-#else
-     save = gq_button_new_with_label(_("_Save"));
-#endif
-     gtk_signal_connect_object(GTK_OBJECT(save), "clicked",
-                               GTK_SIGNAL_FUNC(save_filter), GTK_OBJECT(window));
+
+     g_signal_connect_swapped(save, "clicked",
+                               G_CALLBACK(save_filter), GTK_OBJECT(window));
      gtk_box_pack_start(GTK_BOX(hbox2), save, FALSE, FALSE, 0);
      GTK_WIDGET_UNSET_FLAGS(save, GTK_CAN_FOCUS);
      GTK_WIDGET_SET_FLAGS(save, GTK_CAN_DEFAULT);
      gtk_widget_grab_default(save);
      gtk_widget_show(save);
 
-#if GTK_MAJOR >= 2
      cancel = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-#else
-     cancel = gq_button_new_with_label(_("_Cancel"));
-#endif
+
      GTK_WIDGET_UNSET_FLAGS(cancel, GTK_CAN_FOCUS);
      gtk_box_pack_end(GTK_BOX(hbox2), cancel, FALSE, FALSE, 0);
-     gtk_signal_connect_object(GTK_OBJECT(cancel), "clicked",
-                               (GtkSignalFunc) statusbar_msg,
-                               (gpointer) _("Editing filter cancelled."));
-     gtk_signal_connect_object(GTK_OBJECT(cancel), "clicked",
-                               (GtkSignalFunc) gtk_widget_destroy,
-                               (gpointer) window);
+     g_signal_connect_swapped(cancel, "clicked",
+                               G_CALLBACK(statusbar_msg),
+                               _("Editing filter cancelled."));
+     g_signal_connect_swapped(cancel, "clicked",
+                               G_CALLBACK(gtk_widget_destroy),
+                               window);
      gtk_widget_show(cancel);
 
      gtk_widget_grab_focus(editbox);
@@ -851,7 +796,6 @@ static void save_filter(GtkWidget *window)
 
      text = gtk_object_get_data(GTK_OBJECT(window), "editbox");
 
-#if GTK_MAJOR >= 2
      {
 	  GtkTextBuffer *b = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
 	  GtkTextIter s, e;
@@ -860,9 +804,6 @@ static void save_filter(GtkWidget *window)
 	  gtk_text_buffer_get_end_iter(b, &e);
 	  filtertext = gtk_text_buffer_get_text(b, &s, &e, TRUE);
      }
-#else
-     filtertext = gtk_editable_get_chars(GTK_EDITABLE(text), 0, -1);
-#endif 
 
      filter_clist = gtk_object_get_data(GTK_OBJECT(window), "filter_clist");
      row = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(window), "filter_row"));
@@ -873,9 +814,9 @@ static void save_filter(GtkWidget *window)
 	  goto done;
      }
 
-     assert(filter);
-     assert(servername);
-     assert(basedn);
+     g_assert(filter);
+     g_assert(servername);
+     g_assert(basedn);
      
      if(!filter || !servername || !basedn ) {
 	  /* shouldn't happen */
@@ -983,8 +924,8 @@ static void save_filter(GtkWidget *window)
      }
 
  done:
-     g_free_if(filtertext);
-     g_free_if(flattened);
+     g_free(filtertext);
+     g_free(flattened);
 
      if (is_a_new_filter && filter) free_filter(filter);
 	  
@@ -1116,16 +1057,12 @@ static void indent_toggled(GtkToggleButton *indent, gpointer editbox)
 {
      char *current, *newtext;
 
-#if GTK_MAJOR >= 2
      GtkTextBuffer *b = gtk_text_view_get_buffer(GTK_TEXT_VIEW(editbox));
      GtkTextIter s, e;
-     
+
      gtk_text_buffer_get_start_iter(b, &s);
      gtk_text_buffer_get_end_iter(b, &e);
      current = gtk_text_buffer_get_text(b, &s, &e, TRUE);
-#else
-     current = gtk_editable_get_chars(GTK_EDITABLE(editbox), 0, -1);
-#endif
 
      if(!current) return;
 
@@ -1137,19 +1074,14 @@ static void indent_toggled(GtkToggleButton *indent, gpointer editbox)
 	  newtext = unindent_filter(current);
      }
 
-#if GTK_MAJOR >= 2
      gtk_text_buffer_set_text(b, newtext, strlen(newtext));  /* FIXME: UTF-8 ?? */
-#else
-     gtk_text_set_point(GTK_TEXT(editbox), 0);
-     gtk_text_forward_delete(GTK_TEXT(editbox), gtk_text_get_length(GTK_TEXT(editbox)));
-     gtk_text_insert(GTK_TEXT(editbox), FILTER_EDIT_FONT, NULL, NULL, newtext, -1);
-#endif
+
      g_free(newtext);
      g_free(current);
 
 }
 
-/* 
+/*
    Local Variables:
    c-basic-offset: 5
    End:
