@@ -22,13 +22,14 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: formfill.c,v 1.47 2006/04/05 00:53:55 herzi Exp $ */
+/* $Id: formfill.c 975 2006-09-07 18:44:41Z herzi $ */
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 
 #include <glib.h>
+#include <glib/gi18n.h>
 
 #include <lber.h>
 #include <ldap.h>
@@ -41,8 +42,6 @@
 #include "syntax.h"
 #include "schema.h"
 #include "encode.h"
-#include "i18n.h"
-#include "utf8-compat.h" 
 
 static GList *internalAttrs = NULL;
 
@@ -76,9 +75,9 @@ struct formfill *new_formfill(void)
      form = (struct formfill *) g_new0(struct formfill, 1);
      /* checking for NULL-ness actually is useless for memory
 	allocated through g_new0 et. al. */
-     assert(form);
+     g_assert(form);
 
-     form->attrname[0] = '\0';
+     form->attrname = g_strdup("");
      form->num_inputfields = 1;
      form->displaytype = DISPLAYTYPE_ENTRY;
      form->dt_handler = get_dt_handler(form->displaytype);
@@ -95,7 +94,7 @@ struct formfill *new_formfill(void)
 void free_formlist(GList *formlist)
 {
      GList *n, *f;
-     
+
      for (f = formlist ; f ; f = n) {
 	  n = f->next;
 	  free_formfill( (struct formfill *) f->data);
@@ -120,12 +119,21 @@ void free_formfill_values(struct formfill *form) {
      }
 }
 
-void free_formfill(struct formfill *form)
+void
+free_formfill(struct formfill *form)
 {
-     free_formfill_values(form);
-     if (form->widgetList) g_list_free(form->widgetList);
-     if (form->server) ldapserver_unref(form->server);
-     g_free(form);
+	g_free(form->attrname);
+	form->attrname = NULL;
+
+	free_formfill_values(form);
+	if (form->widgetList) g_list_free(form->widgetList);
+
+	if(form->server) {
+		g_object_unref(form->server);
+		form->server = NULL;
+	}
+
+	g_free(form);
 }
 
 
@@ -169,7 +177,7 @@ char *attr_strip(const char *attr)
 
 static GList *formlist_from_entry_iteration(int error_context, 
 					    LDAP *ld,
-					    struct ldapserver *server,
+					    GqServer *server,
 					    const char *dn, 
 					    int ocvalues_only,
 					    char **attrs,
@@ -222,7 +230,7 @@ static GList *formlist_from_entry_iteration(int error_context,
 	  entry = ldap_first_entry(ld, res);
 	  if(entry) {
 	       char *cc;
-	       
+
 	       for(attr = ldap_first_attribute(ld, entry, &ber); attr ;
 		   attr = ldap_next_attribute(ld, entry, ber)) {
 		    gboolean oc;
@@ -235,16 +243,16 @@ static GList *formlist_from_entry_iteration(int error_context,
 			      continue;
 			 }
 		    }
-		    
+
 		    form = new_formfill();
-		    assert(form);
-		    
-		    form->server = server;
-		    ldapserver_ref(server);
-		    
-		    strncpy(form->attrname, cc, MAX_ATTR_LEN);
+		    g_assert(form);
+
+		    form->server = g_object_ref(server);
+
+		    g_free(form->attrname);
+		    form->attrname = g_strdup(cc);
 		    if (cc) g_free(cc);
-		    
+
 		    oc  = strcasecmp(attr, "objectClass") == 0;
 
 		    if(ocvalues_only == 0 || oc) {
@@ -252,13 +260,13 @@ static GList *formlist_from_entry_iteration(int error_context,
 			 if(bervals) {
 			      for(i = 0; bervals[i]; i++) {
 				   GByteArray *gb = g_byte_array_new();
-				   g_byte_array_append(gb, 
+				   g_byte_array_append(gb,
 						       (guchar*)bervals[i]->bv_val,
 						       bervals[i]->bv_len);
 				   form->values = g_list_append(form->values,
 								gb);
 			      }
-			      
+
 			      form->num_inputfields = i;
 			      ldap_value_free_len(bervals);
 			 }
@@ -284,7 +292,7 @@ static GList *formlist_from_entry_iteration(int error_context,
 }
 
 GList *formlist_from_entry(int error_context, 
-			   struct ldapserver *server, const char *dn, 
+			   GqServer *server, const char *dn, 
 			   int ocvalues_only)
 {
      GList *formlist;
@@ -303,16 +311,7 @@ GList *formlist_from_entry(int error_context,
 
      set_busycursor();
 
-#if GTK_MAJOR >= 2
      statusbar_msg(_("Fetching %1$s from %2$s"), dn, server->name);
-#else
-     {
-	  char *c = NULL;
-	  statusbar_msg(_("Fetching %1$s from %2$s"), 
-			c = decoded_string(dn), server->name);
-	  if (c) free(c);
-     }
-#endif
 
      if( (ld = open_connection(error_context, server)) == NULL) {
           set_normalcursor();
@@ -345,15 +344,18 @@ GList *dup_formlist(GList *oldlist)
      while(oldlist) {
 	  oldform = (struct formfill *) oldlist->data;
 	  newform = new_formfill();
-	  assert(newform);
+	  g_assert(newform);
 
 	  /* no problem with NUL bytes here - new_formfill returns a
              completly NUL inited object */
-	  newform->server = oldform->server;
-	  if (newform->server) ldapserver_ref(newform->server);
+	  if(oldform->server) {
+		  newform->server = g_object_ref(oldform->server);
+	  } else {
+		  newform->server = NULL;
+	  }
 
-	  strncpy(newform->attrname, oldform->attrname,
-		  sizeof(newform->attrname));
+	  g_free(newform->attrname);
+	  newform->attrname = g_strdup(oldform->attrname);
 	  newform->num_inputfields = oldform->num_inputfields;
 	  newform->displaytype = oldform->displaytype;
 	  newform->dt_handler = oldform->dt_handler;
@@ -394,12 +396,9 @@ void dump_formlist(GList *formlist)
 	  while(values) {
 	       if(values->data) {
 		    GByteArray *d = (GByteArray*) values->data;
-/*  		    GByteArray *gb = form->dt_handler->encode(d->data, d->len); */
 		    printf("\t");
 		    fwrite(d->data, d->len, 1, stdout);
 		    printf("\n");
-
-/*  		    g_byte_array_free(gb, TRUE); */
 	       }
 	       values = values->next;
 	  }
@@ -473,7 +472,7 @@ struct formfill *lookup_attribute_using_schema(GList *formlist,
  * sure it is nice to use serverschema for this
  *
  */
-int find_displaytype(int error_context, struct ldapserver *server, 
+int find_displaytype(int error_context, GqServer *server, 
 		     struct formfill *form)
 {
      return get_display_type_of_attr(error_context, server, form->attrname);
@@ -486,7 +485,7 @@ int find_displaytype(int error_context, struct ldapserver *server,
  *
  */
 void set_displaytype(int error_context, 
-		     struct ldapserver *server, struct formfill *form)
+		     GqServer *server, struct formfill *form)
 {
      struct attr_settings *as;
 
@@ -510,34 +509,7 @@ void set_displaytype(int error_context,
      form->dt_handler = get_dt_handler(form->displaytype);
 }
 
-
-/****************** unused functions *********************/
-
-
-#if DEAD_CODE
 /*
- * arrow next to inputfield hit: add empty field below this one
- */
-static void add_field_to_formfill(GList *formlist, char *attr)
-{
-     struct formfill *form;
-
-     while(formlist) {
-
-	  form = (struct formfill *) formlist->data;
-	  if(!strcmp(form->attrname, attr)) {
-	       form->num_inputfields++;
-	       break;
-	  }
-
-	  formlist = formlist->next;
-     }
-
-}
-#endif
-
-
-/* 
    Local Variables:
    c-basic-offset: 5
    End:
