@@ -92,8 +92,9 @@ void record_path(GqTab *tab, GqBrowserNode *entry,
 	  /* currently it is sufficient to keep changes in entry types only */
 	  if (e && G_OBJECT_TYPE(e) != type) {
 	       GString *str = g_string_new("");
-	       g_string_append_printf(str, "%ld:%s",
-				G_OBJECT_TYPE(e), GQ_BROWSER_NODE_GET_CLASS(e)->get_name(e, TRUE));
+	       g_string_append_printf(str, "%d:%s",
+				G_OBJECT_TYPE(e),
+				GQ_BROWSER_NODE_GET_CLASS(e)->get_name(e, TRUE));
 
 	       GQ_TAB_BROWSE(tab)->cur_path =
 		    g_list_insert(GQ_TAB_BROWSE(tab)->cur_path, str->str, 0);
