@@ -25,9 +25,10 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: gq-xml.c,v 1.15 2006/04/05 00:53:55 herzi Exp $ */
+/* $Id: gq-xml.c 975 2006-09-07 18:44:41Z herzi $ */
 
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include <sys/types.h>
@@ -38,12 +39,12 @@
 #include <fcntl.h>
 #include <ctype.h>
 
+#include "configfile.h"
+#include "gq-server-list.h"
 #include "gq-xml.h"
 #include "xmlparse.h"
 #include "xmlutil.h"
-#include "configfile.h"
 #include "util.h"
-#include "i18n.h"
 #include "ldif.h"
 #include "syntax.h"
 #include "filter.h"
@@ -299,21 +300,21 @@ static void schema_serverE(struct parser_context *ctx,
 static void ldapserverS(struct parser_context *ctx,
 			struct tagstack_entry *e)
 {
-    struct ldapserver *server = new_ldapserver();
+    GqServer *server = gq_server_new();
     e->data = server;
-    e->free_data = (free_func) ldapserver_unref;
+    e->free_data = (free_func)g_object_unref;
 }
 
 static void ldapserverE(struct parser_context *ctx,
 			struct tagstack_entry *e)
 {
     struct gq_config *c = peek_tag(ctx->stack, 1)->data;
-    struct ldapserver *server = e->data;
+    GqServer *server = e->data;
 
     if (strcasecmp(server->pwencoding, "Base64") == 0 && server->bindpw[0]) {
 	GByteArray *o = g_byte_array_new();
 	b64_decode(o, server->bindpw, strlen(server->bindpw));
-	
+
 	server->bindpw = g_malloc(o->len + 1);
 	strncpy(server->bindpw, (gchar*)o->data, o->len); /* UTF-8 OK */
 	server->bindpw[o->len] = 0;
@@ -322,7 +323,7 @@ static void ldapserverE(struct parser_context *ctx,
     }
 
     canonicalize_ldapserver(server);
-    config_add_server(c, server);
+    gq_server_list_add(gq_server_list_get(), server);
 
     e->data = NULL;
     e->free_data = NULL;
@@ -331,21 +332,21 @@ static void ldapserverE(struct parser_context *ctx,
 static void ldapserver_nameE(struct parser_context *ctx,
 			     struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
     g_free_and_dup(server->name, (gchar*)e->cdata);
 }
 
 static void ldapserver_ldaphostE(struct parser_context *ctx,
 				 struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
     g_free_and_dup(server->ldaphost, (gchar*)e->cdata);
 }
 
 static void ldapserver_ldapportE(struct parser_context *ctx,
 				 struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     long l = longCDATA(ctx, e);
     if (l >= 0) server->ldapport = l;
@@ -355,7 +356,7 @@ static void ldapserver_ldapportE(struct parser_context *ctx,
 static void ldapserver_basednE(struct parser_context *ctx,
 			       struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
     g_free_and_dup(server->basedn, (gchar*)e->cdata);
 }
 
@@ -363,14 +364,14 @@ static void ldapserver_basednE(struct parser_context *ctx,
 static void ldapserver_binddnE(struct parser_context *ctx,
 			       struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
     g_free_and_dup(server->binddn, (gchar*)e->cdata);
 }
 
 static void ldapserver_bindpwE(struct parser_context *ctx,
 			       struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
     g_free_and_dup(server->bindpw, (gchar*)e->cdata);
 }
 
@@ -378,7 +379,7 @@ static void ldapserver_bindpwE(struct parser_context *ctx,
 static void ldapserver_pw_encodingE(struct parser_context *ctx,
 				    struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
     g_free_and_dup(server->pwencoding, (gchar*)e->cdata);
 }
 
@@ -386,7 +387,7 @@ static void ldapserver_pw_encodingE(struct parser_context *ctx,
 static void ldapserver_bindtypeE(struct parser_context *ctx,
 				 struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     int t = tokenize(token_bindtype, (gchar*)e->cdata);
     server->bindtype = t;
@@ -395,14 +396,14 @@ static void ldapserver_bindtypeE(struct parser_context *ctx,
 static void ldapserver_search_attributeE(struct parser_context *ctx,
 					 struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
     g_free_and_dup(server->searchattr, (gchar*)e->cdata);
 }
 
 static void ldapserver_ask_pwE(struct parser_context *ctx,
 			       struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     int b = booleanCDATA(ctx, e);
     if (b >= 0) server->ask_pw = b;
@@ -411,7 +412,7 @@ static void ldapserver_ask_pwE(struct parser_context *ctx,
 static void ldapserver_hide_internalE(struct parser_context *ctx,
 				      struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     int b = booleanCDATA(ctx, e);
     if (b >= 0) server->hide_internal = b;
@@ -421,7 +422,7 @@ static void ldapserver_hide_internalE(struct parser_context *ctx,
 static void ldapserver_show_refE(struct parser_context *ctx,
 				 struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     int b = booleanCDATA(ctx, e);
     if (b >= 0) server->show_ref = b;
@@ -430,7 +431,7 @@ static void ldapserver_show_refE(struct parser_context *ctx,
 static void ldapserver_enable_tlsE(struct parser_context *ctx,
 				   struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     int b = booleanCDATA(ctx, e);
     if (b >= 0) server->enabletls = b;
@@ -439,7 +440,7 @@ static void ldapserver_enable_tlsE(struct parser_context *ctx,
 static void ldapserver_cache_connectionE(struct parser_context *ctx,
 					 struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     int b = booleanCDATA(ctx, e);
     if (b >= 0) server->cacheconn = b;
@@ -448,7 +449,7 @@ static void ldapserver_cache_connectionE(struct parser_context *ctx,
 static void ldapserver_local_cache_timeoutE(struct parser_context *ctx,
 					    struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     long l = longCDATA(ctx, e);
     if (l >= 0) server->local_cache_timeout = l;
@@ -457,7 +458,7 @@ static void ldapserver_local_cache_timeoutE(struct parser_context *ctx,
 static void ldapserver_maxentriesE(struct parser_context *ctx,
 				   struct tagstack_entry *e)
 {
-    struct ldapserver *server = peek_tag(ctx->stack, 1)->data;
+    GqServer *server = peek_tag(ctx->stack, 1)->data;
 
     long l = longCDATA(ctx, e);
     if (l >= 0) server->maxentries = l;
@@ -622,7 +623,7 @@ static void ldap_attributeS(struct parser_context *ctx,
 	    char *tmp, *t;
 	    struct attr_settings *as;
 
-	    assert(e->attrs[i + 1]);
+	    g_assert(e->attrs[i + 1]);
 
 	    tmp = g_strdup((gchar*)e->attrs[i + 1]);
 	    for (t = tmp ; *t ; t++) *t = tolower(*t);
@@ -658,7 +659,7 @@ static void ldap_attributeE(struct parser_context *ctx,
     struct attr_settings *as;
     gpointer okey;
 
-    assert(e->data);
+    g_assert(e->data);
     as = (struct attr_settings *) e->data;
 
     if (is_default_attr_settings(as)) {
@@ -669,7 +670,7 @@ static void ldap_attributeE(struct parser_context *ctx,
 				     as->name, 
 				     &okey, NULL);
 	g_hash_table_remove(c->attrs, as->name);
-	g_free_if(okey);
+	g_free(okey);
 
 	free_attr_settings(as);
     }
@@ -684,7 +685,7 @@ static void dt_defaultE(struct parser_context *ctx,
 
     long l = longCDATA(ctx, e);
 
-    assert(as);
+    g_assert(as);
 
     if (l >= 0) as->defaultDT = l;
 }
@@ -695,7 +696,7 @@ static void user_friendlyE(struct parser_context *ctx,
     struct attr_settings *as =
 	(struct attr_settings *) peek_tag(ctx->stack, 1)->data;
 
-    assert(as);
+    g_assert(as);
     
     if (e->cdata && strlen((gchar*)e->cdata) > 0) {
 	as->user_friendly = g_strdup((gchar*)e->cdata);
@@ -1076,7 +1077,7 @@ static int dot_gq_upgrade_hack(int error_context, const char *filename)
 			g_string_append(newbuf, "&lt;");
 			changed++;
 			i++;
-		    }		       
+		    }
 		    else if(cfgbuf[i + 1] == '>') {
 			g_string_append(newbuf, "&gt;");
 			changed++;
@@ -1086,35 +1087,9 @@ static int dot_gq_upgrade_hack(int error_context, const char *filename)
 			g_string_append_c(newbuf, cfgbuf[i]);
 		    break;
 
-#if 0 /* no need to escape ' and " at all */
-		case '"':
-		    /* this wasn't escaped at all */
-		    g_string_append(newbuf, "&quot;");
-		    changed++;
-		    break;
-		case '\'':
-		    /* neither was this */
-		    g_string_append(newbuf, "&apos;");
-		    changed++;
-		    break;
-#endif
 		case '&':
-#if 0
-		    /* if it's not the start of an XML escape, it
-		       must be an illegal & */
-		    if(strncmp(cfgbuf + i + 1, "amp;", 4) &&
-		       strncmp(cfgbuf + i + 1, "lt;", 3) &&
-		       strncmp(cfgbuf + i + 1, "gt;", 3) &&
-		       strncmp(cfgbuf + i + 1, "apos;", 5) &&
-		       strncmp(cfgbuf + i + 1, "quot;", 5)) {
-#endif
 		    g_string_append(newbuf, "&amp;");
 		    changed++;
-#if 0
-		    }
-		    else
-			g_string_append_c(newbuf, cfgbuf[i]);
-#endif
 		    break;
 		default:
 		    g_string_append_c(newbuf, cfgbuf[i]);
@@ -1129,7 +1104,7 @@ static int dot_gq_upgrade_hack(int error_context, const char *filename)
 
 		int l = strlen(filename) + 20;
 		char *tmp = g_malloc(l);
-		snprintf(tmp, l, "%s.tmp", filename);
+		g_snprintf(tmp, l, "%s.tmp", filename);
 
 		unlink(tmp); /* provide very minor security */
 		fd = open(tmp, O_CREAT | O_WRONLY, 
