@@ -2,7 +2,7 @@
     GQ -- a GTK-based LDAP client is
     Copyright (C) 1998-2003 Bert Vermeulen
     Copyright (C) 2002-2003 Peter Stamfest
-    
+
     This program is released under the Gnu General Public License with
     the additional exemption that compiling, linking, and/or using
     OpenSSL is allowed.
@@ -22,11 +22,12 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: state.c,v 1.14 2006/04/05 00:53:55 herzi Exp $ */
+/* $Id: state.c 975 2006-09-07 18:44:41Z herzi $ */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+# include  <config.h>
+#endif /* HAVE_CONFIG_H */
 #include <stdlib.h>
-#include <assert.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -34,6 +35,8 @@
 #include <fcntl.h>
 #include <errno.h>
 
+#include <glib/gi18n.h>
+#include <glib/gmessages.h>
 #include <gtk/gtk.h>
 
 #include "xmlparse.h"
@@ -41,7 +44,6 @@
 #include "util.h"
 #include "errorchain.h"
 #include "xmlutil.h"
-#include "i18n.h"
 #include "state.h"
 #include "encode.h"		/* gq_codeset */
 
@@ -103,7 +105,7 @@ static struct state_value *new_state_value(enum state_value_type t)
 
 static void free_state_value(struct state_value *v) 
 {
-    assert(v);
+    g_assert(v);
     switch (v->type) {
     case SV_int: 
 	g_free(v->val.int_val);
@@ -136,7 +138,7 @@ static struct state_entity *new_state_entity()
 
 static gboolean ghr_free_value(char *key, struct state_value *v, gpointer ud)
 {
-    g_free_if(key);
+    g_free(key);
     free_state_value(v);
     return TRUE;
 }
@@ -146,14 +148,14 @@ void free_state_entity(struct state_entity *e);
 static gboolean ghr_free_entity(char *key, 
 				struct state_entity *e, gpointer ud)
 {
-    g_free_if(key);
+    g_free(key);
     free_state_entity(e);
     return TRUE;
 }
 
 void free_state_entity(struct state_entity *e)
 {
-    assert(e);
+    g_assert(e);
     g_hash_table_foreach_remove(e->values, (GHRFunc) ghr_free_value, NULL);
     g_hash_table_foreach_remove(e->entities, (GHRFunc) ghr_free_entity, NULL);
     g_hash_table_destroy(e->values);
@@ -223,8 +225,8 @@ int state_value_get_int(const char *state_name,
 {
     struct state_value *val;
     struct state_entity *e = lookup_entity(state_name);
-    assert(e);
-    assert(e->values);
+    g_assert(e);
+    g_assert(e->values);
 
     val = g_hash_table_lookup(e->values, value_name);
     if (val) {
@@ -245,8 +247,8 @@ void state_value_set_int(const char *state_name,
 {
     struct state_value *val;
     struct state_entity *e = lookup_entity(state_name);
-    assert(e);
-    assert(e->values);
+    g_assert(e);
+    g_assert(e->values);
 
     val = g_hash_table_lookup(e->values, value_name);
     if (val) {
@@ -266,8 +268,8 @@ const char *state_value_get_string(const char *state_name,
 {
     struct state_value *val;
     struct state_entity *e = lookup_entity(state_name);
-    assert(e);
-    assert(e->values);
+    g_assert(e);
+    g_assert(e->values);
 
     val = g_hash_table_lookup(e->values, value_name);
     if (val) {
@@ -290,8 +292,8 @@ void state_value_set_string(const char *state_name,
 {
     struct state_value *val;
     struct state_entity *e = lookup_entity(state_name);
-    assert(e);
-    assert(e->values);
+    g_assert(e);
+    g_assert(e->values);
 
     val = g_hash_table_lookup(e->values, value_name);
     if (val) {
@@ -310,8 +312,8 @@ const GList *state_value_get_list(const char *state_name,
 {
     struct state_value *val;
     struct state_entity *e = lookup_entity(state_name);
-    assert(e);
-    assert(e->values);
+    g_assert(e);
+    g_assert(e->values);
 
     val = g_hash_table_lookup(e->values, value_name);
     if (val) {
@@ -350,8 +352,8 @@ void state_value_set_list(const char *state_name,
     struct state_entity *e = lookup_entity(state_name);
     const GList *I;
 
-    assert(e);
-    assert(e->values);
+    g_assert(e);
+    g_assert(e->values);
 
     val = g_hash_table_lookup(e->values, value_name);
     if (val) {
@@ -469,17 +471,17 @@ GtkWidget *stateful_gtk_window_new(GtkWindowType type,
 	gtk_window_set_default_size(GTK_WINDOW(wid), w, h);
     }
 
-    gtk_signal_connect(GTK_OBJECT(wid), "size-allocate",
-		       GTK_SIGNAL_FUNC(width_height_state),
-		       (gpointer) ud);
+    g_signal_connect(wid, "size-allocate",
+		       G_CALLBACK(width_height_state),
+		       ud);
 
-    gtk_signal_connect_after(GTK_OBJECT(wid), "realize",
-			     GTK_SIGNAL_FUNC(window_realized),
-			     (gpointer) ud);
+    g_signal_connect_after(wid, "realize",
+			     G_CALLBACK(window_realized),
+			     ud);
 
-    gtk_signal_connect(GTK_OBJECT(wid), "unrealize",
-		       GTK_SIGNAL_FUNC(window_unrealized),
-		       (gpointer) ud);
+    g_signal_connect(wid, "unrealize",
+		       G_CALLBACK(window_unrealized),
+		       ud);
     
     return wid;
 }
@@ -609,24 +611,12 @@ void save_state() {
 	return;
     }
     wc->outfile = fdopen(fd, "w");
-    
-#if GTK_MAJOR >= 2
+
     config_write(wc, "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\n");
-#else
-    { 
-	char xmldecl[255];
-	
-	snprintf(xmldecl, sizeof(xmldecl),
-		 "<?xml version=\"1.0\" encoding=\"%s\" standalone=\"yes\"?>\n",
-		 gq_codeset);
-	
-	config_write(wc, xmldecl);
-    }
-#endif
 
     config_write_start_tag(wc, "gq-state", NULL);
     wc->indent++;
-    
+
     g_hash_table_foreach(entities,
 			 (GHFunc) save_single_entity,
 			 wc);
@@ -638,10 +628,10 @@ void save_state() {
 
     if (rename(tmpstatefile, statefile) != 0) {
 	error_push(save_context,
-		   _("Could not replace old configuration (%1$s) with the new one (%2$s):\n%3$s\n"), 
+		   _("Could not replace old configuration (%1$s) with the new one (%2$s):\n%3$s\n"),
 		   statefile, tmpstatefile, strerror(errno));
     }
-    
+
     g_free(tmpstatefile);
 }
 
@@ -757,7 +747,7 @@ static void state_valueE(struct parser_context *ctx,
     if (n != NULL && v->type != 0) {
 	char *ep;
 
-	assert(v);
+	g_assert(v);
 
 	switch (v->type) {
 	case SV_int: 
