@@ -22,7 +22,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: tdefault.c,v 1.3 2003/10/18 08:13:17 stamfest Exp $ */
+/* $Id: tdefault.c 955 2006-08-31 19:15:21Z herzi $ */
 
 #include <string.h>
 
@@ -42,7 +42,7 @@ void create_tdefault_edit_window(GtkWidget *dummy, GtkWidget *templatewin)
      GList *attrlist, *attrlist1, *attrlist2, *tduilist, *combolist;
      GtkWidget *tdefaultwin, *vbox1, *hbox1, *hbox2, *table1;
      GtkWidget *label, *button, *combo, *entry;
-     struct ldapserver *server;
+     GqServer *server;
      struct gq_template *tmpl;
      struct tdefault_ui *tdui;
      int num_attrs, row, i;
@@ -66,8 +66,8 @@ void create_tdefault_edit_window(GtkWidget *dummy, GtkWidget *templatewin)
 
      tdefaultwin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
      gtk_container_border_width(GTK_CONTAINER(tdefaultwin), 10);
-     gtk_signal_connect(GTK_OBJECT(tdefaultwin), "key_press_event",
-			(GtkSignalFunc) close_on_esc, (gpointer) tdefaultwin);
+     g_signal_connect(tdefaultwin, "key_press_event",
+			G_CALLBACK(close_on_esc), tdefaultwin);
      gtk_window_set_title(GTK_WINDOW(tdefaultwin), "GQ: default values");
 
      vbox1 = gtk_vbox_new(FALSE, 0);
@@ -173,16 +173,13 @@ void create_tdefault_edit_window(GtkWidget *dummy, GtkWidget *templatewin)
 	       combo = gtk_combo_new();
 	       gtk_widget_show(combo);
 	       tdui->passwdscheme = combo;
-	       i = 0;
 	       combolist = NULL;
-#ifdef HAVE_LIBCRYPTO
-	       /* PSt: Note: without libcrypto, we should not even
-                  have a combobox! */
 
-	       while(cryptmap[i].keyword[0])
-		    combolist = g_list_append(combolist, 
-					      (char *) cryptmap[i++].keyword);
-#endif
+	       for(i = 0; cryptmap[i].keyword[0]; i++) {
+		    combolist = g_list_append(combolist,
+					      (char *) cryptmap[i].keyword);
+	       }
+
 	       gtk_combo_set_popdown_strings(GTK_COMBO(combo), combolist);
 	       if (combolist) g_list_free(combolist);
 
@@ -211,8 +208,8 @@ void create_tdefault_edit_window(GtkWidget *dummy, GtkWidget *templatewin)
 	  }
 
 	  if(row != 1)
-	       gtk_signal_connect_object(GTK_OBJECT(GTK_COMBO(tdui->type)->entry), "changed",
-					 (GtkSignalFunc) tdefault_type_changed, (gpointer) tdui);
+	       g_signal_connect_swapped(GTK_COMBO(tdui->type)->entry, "changed",
+					 G_CALLBACK(tdefault_type_changed), tdui);
 
 	  tduilist = g_list_append(tduilist, tdui);
 	  row++;
