@@ -22,15 +22,18 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: template.c,v 1.17 2006/04/05 00:53:55 herzi Exp $ */
+/* $Id: template.c 975 2006-09-07 18:44:41Z herzi $ */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif /* HAVE_CONFIG_H */
 
 #ifdef HAVE_LDAP_STR2OBJECTCLASS
 
 #include <string.h>
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include <lber.h>
@@ -40,14 +43,13 @@
 #include "mainwin.h"
 #include "configfile.h"
 #include "common.h"
+#include "gq-tab-schema.h"
 #include "util.h"
 #include "schema.h"
-#include "schemabrowse.h"
 #include "template.h"
 #include "tdefault.h"
 #include "errorchain.h"
 #include "debug.h"
-#include "i18n.h"
 #include "state.h"
 
 
@@ -71,7 +73,7 @@ struct gq_template *new_template(void)
 
 void free_template(struct gq_template *tmpl)
 {
-     g_free_if(tmpl->name);
+     g_free(tmpl->name);
      
      if (tmpl->objectclasses) {
 	  g_list_foreach(tmpl->objectclasses, (GFunc) g_free, NULL);
@@ -80,7 +82,7 @@ void free_template(struct gq_template *tmpl)
      g_free(tmpl);
 }
 
-void create_template_edit_window(struct ldapserver *server, 
+void create_template_edit_window(GqServer *server, 
 				 const char *templatename,
 				 GtkWidget *modalFor)
 {
@@ -128,21 +130,20 @@ void create_template_edit_window(struct ldapserver *server,
      }
 
      templatewin = stateful_gtk_window_new(GTK_WINDOW_TOPLEVEL,
-					   "template", 700, 450); 
+					   "template", 700, 450);
      if (modalFor) {
-	  assert(GTK_IS_WINDOW(modalFor));
+	  g_assert(GTK_IS_WINDOW(modalFor));
 	  gtk_window_set_modal(GTK_WINDOW(templatewin), TRUE);
 	  gtk_window_set_transient_for(GTK_WINDOW(templatewin),
 				       GTK_WINDOW(modalFor));
      }
 
-     gtk_object_set_data_full(GTK_OBJECT(templatewin), "server", 
-			      server, (GtkDestroyNotify) ldapserver_unref);
-     ldapserver_ref(server);
+     gtk_object_set_data_full(GTK_OBJECT(templatewin), "server",
+			      g_object_ref(server), g_object_unref);
 
      gtk_container_border_width(GTK_CONTAINER(templatewin), 10);
-     gtk_signal_connect(GTK_OBJECT(templatewin), "key_press_event",
-			(GtkSignalFunc) close_on_esc, (gpointer) templatewin);
+     g_signal_connect(templatewin, "key_press_event",
+			G_CALLBACK(close_on_esc), templatewin);
 
      vbox1 = gtk_vbox_new(FALSE, 0);
      gtk_container_add(GTK_CONTAINER(templatewin), vbox1);
@@ -168,15 +169,14 @@ void create_template_edit_window(struct ldapserver *server,
 #ifdef OLD_FOCUS_HANDLING
      GTK_WIDGET_UNSET_FLAGS(oclist, GTK_CAN_FOCUS);
 #endif
-     gtk_object_set_data_full(GTK_OBJECT(oclist), "server", 
-			      server, (GtkDestroyNotify) ldapserver_unref);
-     ldapserver_ref(server);
+     gtk_object_set_data_full(GTK_OBJECT(oclist), "server",
+			      g_object_ref(server), g_object_unref);
 
      gtk_object_set_data(GTK_OBJECT(templatewin), "oclist", oclist);
      gtk_clist_set_compare_func(GTK_CLIST(oclist), clistcasecmp);
      gtk_clist_column_titles_passive(GTK_CLIST(oclist));
-     gtk_signal_connect(GTK_OBJECT(oclist), "select_row",
-                        (GtkSignalFunc) select_oc_from_clist, NULL);
+     g_signal_connect(oclist, "select_row",
+                        G_CALLBACK(select_oc_from_clist), NULL);
      gtk_widget_show(oclist);
      gtk_container_add(GTK_CONTAINER(scrwin), oclist);
 
@@ -199,8 +199,8 @@ void create_template_edit_window(struct ldapserver *server,
      arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
      gtk_widget_show(arrow);
      gtk_container_add(GTK_CONTAINER(button), arrow);
-     gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			(GtkSignalFunc) arrow_button_callback, templatewin);
+     g_signal_connect(button, "clicked",
+			G_CALLBACK(arrow_button_callback), templatewin);
      gtk_widget_show(button);
      gtk_box_pack_start(GTK_BOX(vbox3), button, TRUE, TRUE, 10);
 
@@ -214,8 +214,8 @@ void create_template_edit_window(struct ldapserver *server,
      arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
      gtk_widget_show(arrow);
      gtk_container_add(GTK_CONTAINER(button), arrow);
-     gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			(GtkSignalFunc) arrow_button_callback, templatewin);
+     g_signal_connect(button, "clicked",
+			G_CALLBACK(arrow_button_callback), templatewin);
      gtk_widget_show(button);
      gtk_box_pack_start(GTK_BOX(vbox3), button, TRUE, TRUE, 10);
 
@@ -231,14 +231,13 @@ void create_template_edit_window(struct ldapserver *server,
 #ifdef OLD_FOCUS_HANDLING
      GTK_WIDGET_UNSET_FLAGS(templatelist, GTK_CAN_FOCUS);
 #endif
-     gtk_object_set_data_full(GTK_OBJECT(templatelist), "server", 
-			      server, (GtkDestroyNotify) ldapserver_unref);
-     ldapserver_ref(server);
+     gtk_object_set_data_full(GTK_OBJECT(templatelist), "server",
+			      g_object_ref(server), g_object_unref);
 
      gtk_object_set_data(GTK_OBJECT(templatewin), "templatelist", templatelist);
      gtk_clist_column_titles_passive(GTK_CLIST(templatelist));
-     gtk_signal_connect(GTK_OBJECT(templatelist), "select_row",
-                        (GtkSignalFunc) select_oc_from_clist, NULL);
+     g_signal_connect(templatelist, "select_row",
+                        G_CALLBACK(select_oc_from_clist), NULL);
      gtk_widget_show(templatelist);
      gtk_container_add(GTK_CONTAINER(scrwin), templatelist);
 
@@ -258,13 +257,12 @@ void create_template_edit_window(struct ldapserver *server,
      GTK_WIDGET_UNSET_FLAGS(clist, GTK_CAN_FOCUS);
 #endif
      gtk_object_set_data_full(GTK_OBJECT(clist), "server",
-			      server, (GtkDestroyNotify) ldapserver_unref);
-     ldapserver_ref(server);
+			      g_object_ref(server), g_object_unref);
 
      gtk_object_set_data(GTK_OBJECT(templatewin), "reqdattr", clist);
      gtk_clist_column_titles_passive(GTK_CLIST(clist));
-     gtk_signal_connect(GTK_OBJECT(clist), "select_row",
-                        (GtkSignalFunc) select_at_from_clist, NULL);
+     g_signal_connect(clist, "select_row",
+                        G_CALLBACK(select_at_from_clist), NULL);
      gtk_widget_show(clist);
      gtk_container_add(GTK_CONTAINER(scrwin), clist);
      gtk_box_pack_start(GTK_BOX(vbox4), scrwin, TRUE, TRUE, 0);
@@ -279,14 +277,13 @@ void create_template_edit_window(struct ldapserver *server,
 #ifdef OLD_FOCUS_HANDLING
      GTK_WIDGET_UNSET_FLAGS(clist, GTK_CAN_FOCUS);
 #endif
-     gtk_object_set_data_full(GTK_OBJECT(clist), "server", 
-			      server, (GtkDestroyNotify) ldapserver_unref);
-     ldapserver_ref(server);
+     gtk_object_set_data_full(GTK_OBJECT(clist), "server",
+			      g_object_ref(server), g_object_unref);
 
      gtk_object_set_data(GTK_OBJECT(templatewin), "allowedattr", clist);
      gtk_clist_column_titles_passive(GTK_CLIST(clist));
-     gtk_signal_connect(GTK_OBJECT(clist), "select_row",
-                        (GtkSignalFunc) select_at_from_clist, NULL);
+     g_signal_connect(clist, "select_row",
+                        G_CALLBACK(select_at_from_clist), NULL);
      gtk_widget_show(clist);
      gtk_container_add(GTK_CONTAINER(scrwin), clist);
      gtk_box_pack_start(GTK_BOX(vbox4), scrwin, TRUE, TRUE, 0);
@@ -302,9 +299,9 @@ void create_template_edit_window(struct ldapserver *server,
 #ifdef OLD_FOCUS_HANDLING
      GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
 #endif
-     gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			(GtkSignalFunc) create_tdefault_edit_window,
-			(gpointer) templatewin);
+     g_signal_connect(button, "clicked",
+			G_CALLBACK(create_tdefault_edit_window),
+			templatewin);
      gtk_widget_show(button);
      gtk_box_pack_start(GTK_BOX(hbox2), button, FALSE, FALSE, 0);
 #endif
@@ -321,9 +318,9 @@ void create_template_edit_window(struct ldapserver *server,
      entry = gtk_entry_new();
      gtk_entry_set_max_length(GTK_ENTRY(entry), 127);
      gtk_object_set_data(GTK_OBJECT(templatewin), "templatenamebox", entry);
-     gtk_signal_connect(GTK_OBJECT(entry), "activate",
-			(GtkSignalFunc) save_template_callback,
-			(gpointer) templatewin);
+     g_signal_connect(entry, "activate",
+			G_CALLBACK(save_template_callback),
+			templatewin);
      gtk_widget_show(entry);
      gtk_box_pack_start(GTK_BOX(hbox3), entry, FALSE, FALSE, 10);
 
@@ -332,28 +329,20 @@ void create_template_edit_window(struct ldapserver *server,
      gtk_box_pack_start(GTK_BOX(vbox1), hbox4, FALSE, FALSE, 10);
 
      /* Save */
-#if GTK_MAJOR >= 2
      button = gtk_button_new_from_stock(GTK_STOCK_SAVE);
-#else
-     button = gq_button_new_with_label(_("_Save"));
-#endif
      GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
-     gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			(GtkSignalFunc) save_template_callback,
-			(gpointer) templatewin);
+     g_signal_connect(button, "clicked",
+			G_CALLBACK(save_template_callback),
+			templatewin);
      gtk_widget_show(button);
      gtk_box_pack_start(GTK_BOX(hbox4), button, FALSE, FALSE, 0);
      gtk_widget_grab_default(button);
 
      /* Cancel */
-#if GTK_MAJOR >= 2
      button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-#else
-     button = gq_button_new_with_label(_("_Cancel"));
-#endif
-     gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-			       (GtkSignalFunc) gtk_widget_destroy,
-			       (gpointer) templatewin);
+     g_signal_connect_swapped(button, "clicked",
+			       G_CALLBACK(gtk_widget_destroy),
+			       templatewin);
      gtk_widget_show(button);
      gtk_box_pack_end(GTK_BOX(hbox4), button, FALSE, FALSE, 0);
 
@@ -406,7 +395,7 @@ void fill_new_template(GtkWidget *window)
      GList *list;
      GtkWidget *oclist, *templatelist;
      LDAPObjectClass *oc;
-     struct ldapserver *server;
+     GqServer *server;
      char *ocname[1];
 
      if( (oclist = gtk_object_get_data(GTK_OBJECT(window), "oclist")) == NULL)
@@ -524,7 +513,7 @@ static void build_used_attrs_list(GtkWidget *window, int context)
 {
      LDAPObjectClass *oc;
      GtkWidget *templatelist, *reqdlist, *allowedlist;
-     struct ldapserver *server;
+     GqServer *server;
      struct server_schema *ss;
      int i, attr;
      char *objectclass, *dummy[1];
